@@ -6,7 +6,7 @@ from transformers import AutoModelForSequenceClassification, AutoTokenizer
 from autoads.keywords import get_keywords_from_api_and_url,get_keywords_from_google
 from autoads.models import get_similarity_api,get_similarity_scrape,get_lfmfuf_predictions
 
-seed_keywords = ["crypto 401k", "real estate 401k", "esg 401k", "business 401k", "business crypto 401k", "business esg 401k",] 
+seed_keywords = ['business roth 401k', 'business 401k mutual funds', 'business 401k brokerage window', 'business alt401k', 'business 401k target date funds', 'business 401k plans'] 
 
 #Credentials/Settings for Dataforseo Api 
 email = 'weilbacherindustries@gmail.com' # email in data for seo
@@ -14,7 +14,7 @@ api_key = '05f014a493983975' # api key for data for seo
 df_api_path = 'data/df_api.csv' # filename for api keywords
 
 #Credentials/Settings for Scraping
-scrape = True # keep true if you want to scrape urls
+scrape = False # keep true if you want to scrape urls
 depth = 1 # depth for scraping range from 1 to 4
 urls = ['capchase.com','pipe.com'] # urls to scrape 
 exclude = ['twitter', 'google', 'facebook', 'linkedin', 'youtube'] # sites to exclude
